import request from '@/utils/request'

// 查询项目拓扑列表
export function listTopology(query) {
    return request({
        url: '/device/topology/list',
        method: 'get',
        params: query
    })
}

// 查询项目拓扑详细
export function getTopology(itemId) {
    return request({
        url: '/device/topology/' + itemId,
        method: 'get'
    })
}

// 新增项目拓扑
export function addTopology(data) {
    return request({
        url: '/device/topology',
        method: 'post',
        data: data
    })
}

// 修改项目拓扑
export function updateTopology(data) {
    return request({
        url: '/device/topology',
        method: 'put',
        data: data
    })
}

// 删除项目拓扑
export function delTopology(itemId) {
    return request({
        url: '/device/topology/' + itemId,
        method: 'delete'
    })
}
